@@ -2,15 +2,20 @@ from typing import List
 
 from google.protobuf.timestamp_pb2 import Timestamp
 from terrascope_api import TerrascopeAsyncClient
-from terrascope_api.models.analysis_computation_pb2 import AnalysisComputationCreateRequest, \
-    AnalysisComputationRunRequest, AnalysisComputation, \
-    AnalysisComputationGetRequest, AnalysisComputationListRequest
-from terrascope_api.models.analysis_config_pb2 import AnalysisConfigCreateRequest, AnalysisConfigGetRequest, \
-    AnalysisConfigListRequest, AnalysisConfig
-from terrascope_api.models.analysis_pb2 import Analysis, AnalysisCreateRequest, \
-    AnalysisGetRequest, AnalysisListRequest
-from terrascope_api.models.analysis_version_pb2 import AnalysisVersionListRequest, AnalysisVersionGetRequest, \
-    AnalysisVersionCreateRequest, AnalysisVersion
+from terrascope_api.models.analysis_computation_pb2 import (
+    AnalysisComputationCreateRequest, AnalysisComputationRunRequest, AnalysisComputation, AnalysisComputationGetRequest,
+    AnalysisComputationListRequest
+)
+from terrascope_api.models.analysis_config_pb2 import (
+    AnalysisConfigCreateRequest, AnalysisConfigGetRequest, AnalysisConfigListRequest, AnalysisConfigDeactivateRequest,
+    AnalysisConfig
+)
+from terrascope_api.models.analysis_pb2 import (
+    Analysis, AnalysisCreateRequest, AnalysisGetRequest, AnalysisListRequest
+)
+from terrascope_api.models.analysis_version_pb2 import (
+    AnalysisVersionListRequest, AnalysisVersionGetRequest, AnalysisVersionCreateRequest, AnalysisVersion
+)
 from terrascope_api.models.common_models_pb2 import Pagination
 
 from terrascope.sdk.builder.analysis import AnalysisManifest, AnalysisConfiguration
@@ -411,7 +416,7 @@ class APIAnalysisConfig:
         """
         pass
 
-    async def deactivate(self, analysis_config_ids: List):
+    async def deactivate(self, analysis_config_ids: List[str]):
         """
         Deactivate the specific configuration of an analysis_version. Deactivated analysis_configs will no longer
         show up in searches, but metadata can still be retrieved for deactivated analysis_configs via the get endpoint.
@@ -420,7 +425,13 @@ class APIAnalysisConfig:
         :param analysis_config_ids:
         :return:
         """
-        pass
+        analysis_config_deactivate_request = AnalysisConfigDeactivateRequest(
+            ids=analysis_config_ids
+        )
+        analysis_config_deactivate_response = await self.__client.api.analysis_config.deactivate(
+            analysis_config_deactivate_request, timeout=self.__timeout)
+
+        return analysis_config_deactivate_response
 
     async def delete(self, analysis_config_ids: List):
         """
