@@ -743,9 +743,7 @@ class TestAlgorithmComputation:
                                                                             algorithm_manifest=manifest)
 
         config = AlgorithmConfiguration()
-        # config.add_data_source(data_type=DataType.PINGS, data_source=DataSource.WEJO)
-        config.add_data_source(data_type=DataType.OPTICAL_IMAGERY, data_source=DataSource.PLANET_SKYSATCOLLECT)
-        config.add_data_source(data_type=DataType.OPTICAL_IMAGERY, data_source=DataSource.AIRBUS_PHR1A)
+        config.add_data_source(data_type=DataType.PINGS, data_source=DataSource.WEJO)
 
         device_visit_algorithm_config = await sdk.algorithm_config.create(
             algorithm_version_id=device_visit_algorithm_version.id,
